@@ -41,14 +41,14 @@
 #-----------------------------------------------------#
 # External libraries
 from tensorflow import keras
-from keras_applications.resnext import ResNeXt101
+from keras_applications.resnext import ResNeXt101 as BaseModel
 # Internal libraries
 from aucmedi.neural_network.architectures import Architecture_Base
 
 #-----------------------------------------------------#
 #           Architecture class: ResNeXt101            #
 #-----------------------------------------------------#
-class Architecture_ResNeXt101(Architecture_Base):
+class ResNeXt101(Architecture_Base):
     #---------------------------------------------#
     #                Initialization               #
     #---------------------------------------------#
@@ -67,17 +67,16 @@ class Architecture_ResNeXt101(Architecture_Base):
         else : model_weights = None
 
         # Obtain ResNeXt101 as base model
-        base_model = ResNeXt101(include_top=False, weights=model_weights,
-                                input_tensor=None, input_shape=self.input,
-                                pooling=None, backend=keras.backend,
-                                layers=keras.layers, models=keras.models,
-                                utils=keras.utils)
+        base_model = BaseModel(include_top=False, weights=model_weights,
+                               input_tensor=None, input_shape=self.input,
+                               pooling=None, backend=keras.backend,
+                               layers=keras.layers, models=keras.models,
+                               utils=keras.utils)
         top_model = base_model.output
 
         # Add classification head
         model = self.classifier.build(model_input=base_model.input,
-                                      model_output=top_model,
-                                      two_dim=True)
+                                      model_output=top_model)
 
         # Return created model
         return model
