@@ -40,14 +40,14 @@
 #                   Library imports                   #
 #-----------------------------------------------------#
 # External libraries
-from tensorflow.keras.applications.vgg16 import VGG16
+from tensorflow.keras.applications.vgg16 import VGG16 as BaseModel
 # Internal libraries
 from aucmedi.neural_network.architectures import Architecture_Base
 
 #-----------------------------------------------------#
 #              Architecture class: VGG16              #
 #-----------------------------------------------------#
-class Architecture_VGG16(Architecture_Base):
+class VGG16(Architecture_Base):
     #---------------------------------------------#
     #                Initialization               #
     #---------------------------------------------#
@@ -66,15 +66,14 @@ class Architecture_VGG16(Architecture_Base):
         else : model_weights = None
 
         # Obtain VGG16 as base model
-        base_model = VGG16(include_top=False, weights=model_weights,
-                           input_tensor=None, input_shape=self.input,
-                           pooling=None)
+        base_model = BaseModel(include_top=False, weights=model_weights,
+                               input_tensor=None, input_shape=self.input,
+                               pooling=None)
         top_model = base_model.output
 
         # Add classification head
         model = self.classifier.build(model_input=base_model.input,
-                                      model_output=top_model,
-                                      two_dim=True)
+                                      model_output=top_model)
 
         # Return created model
         return model
