@@ -49,7 +49,7 @@ from aucmedi.neural_network.architectures import Architecture_Base
 #-----------------------------------------------------#
 #           Architecture class: DenseNet169           #
 #-----------------------------------------------------#
-class Architecture_DenseNet169(Architecture_Base):
+class DenseNet169(Architecture_Base):
     #---------------------------------------------#
     #                Initialization               #
     #---------------------------------------------#
@@ -68,16 +68,15 @@ class Architecture_DenseNet169(Architecture_Base):
         else : model_weights = None
 
         # Obtain DenseNet169 as base model
-        DenseNet169, preprocess_input = Classifiers.get("densenet169")
-        base_model = DenseNet169(include_top=False, weights=model_weights,
-                                 input_tensor=None, input_shape=self.input,
-                                 pooling=None)
+        BaseModel, preprocess_input = Classifiers.get("densenet169")
+        base_model = BaseModel(include_top=False, weights=model_weights,
+                               input_tensor=None, input_shape=self.input,
+                               pooling=None)
         top_model = base_model.output
 
         # Add classification head
         model = self.classifier.build(model_input=base_model.input,
-                                      model_output=top_model,
-                                      two_dim=False)
+                                      model_output=top_model)
 
         # Return created model
         return model
