@@ -49,7 +49,7 @@ from aucmedi.neural_network.architectures import Architecture_Base
 #-----------------------------------------------------#
 #            Architecture class: ResNeXt50            #
 #-----------------------------------------------------#
-class Architecture_ResNeXt50(Architecture_Base):
+class ResNeXt50(Architecture_Base):
     #---------------------------------------------#
     #                Initialization               #
     #---------------------------------------------#
@@ -68,16 +68,15 @@ class Architecture_ResNeXt50(Architecture_Base):
         else : model_weights = None
 
         # Obtain ResNeXt50 as base model
-        ResNeXt50, preprocess_input = Classifiers.get("resnext50")
-        base_model = ResNeXt50(include_top=False, weights=model_weights,
+        BaseModel, preprocess_input = Classifiers.get("resnext50")
+        base_model = BaseModel(include_top=False, weights=model_weights,
                                input_tensor=None, input_shape=self.input,
                                pooling=None)
         top_model = base_model.output
 
         # Add classification head
         model = self.classifier.build(model_input=base_model.input,
-                                      model_output=top_model,
-                                      two_dim=False)
+                                      model_output=top_model)
 
         # Return created model
         return model
